@@ -25,6 +25,7 @@ from patchwork.steps.ExtractModelResponse.ExtractModelResponse import (
 from patchwork.steps.ExtractPackageManagerFile.ExtractPackageManagerFile import (
     ExtractPackageManagerFile,
 )
+from patchwork.steps.FileAgent.FileAgent import FileAgent
 from patchwork.steps.FilterBySimilarity.FilterBySimilarity import FilterBySimilarity
 from patchwork.steps.FixIssue.FixIssue import FixIssue
 from patchwork.steps.GetTypescriptTypeInfo.GetTypescriptTypeInfo import (
@@ -33,6 +34,7 @@ from patchwork.steps.GetTypescriptTypeInfo.GetTypescriptTypeInfo import (
 from patchwork.steps.GitHubAgent.GitHubAgent import GitHubAgent
 from patchwork.steps.JoinList.JoinList import JoinList
 from patchwork.steps.LLM.LLM import LLM
+from patchwork.steps.ManageEngineAgent.ManageEngineAgent import ManageEngineAgent
 from patchwork.steps.ModifyCode.ModifyCode import ModifyCode
 from patchwork.steps.ModifyCodeOnce.ModifyCodeOnce import ModifyCodeOnce
 from patchwork.steps.PR.PR import PR
@@ -81,6 +83,7 @@ __all__ = [
     "ExtractPackageManagerFile",
     "FilterBySimilarity",
     "FixIssue",
+    "FileAgent",
     "LLM",
     "ModifyCode",
     "ModifyCodePB",
@@ -108,4 +111,5 @@ __all__ = [
     "JoinListPB",
     "GetTypescriptTypeInfo",
     "BrowserUse",
+    "ManageEngineAgent",
 ]
